# Generated by roxygen2: do not edit by hand

export(ccsr_changelog)
export(ccsr_map)
export(download_ccsr)
export(download_trend_tables)
export(get_ccsr_description)
export(hcup_citation)
export(list_ccsr_versions)
export(list_trend_table_sheets)
export(read_ccsr)
export(read_trend_table)
importFrom(dplyr,across)
importFrom(dplyr,all_of)
importFrom(dplyr,arrange)
importFrom(dplyr,bind_rows)
importFrom(dplyr,desc)
importFrom(dplyr,distinct)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,row_number)
importFrom(dplyr,select)
importFrom(dplyr,ungroup)
importFrom(httr2,req_perform)
importFrom(httr2,req_timeout)
importFrom(httr2,req_user_agent)
importFrom(httr2,request)
importFrom(httr2,resp_body_raw)
importFrom(httr2,resp_body_string)
importFrom(readr,cols)
importFrom(readr,locale)
importFrom(readr,read_csv)
importFrom(readxl,excel_sheets)
importFrom(readxl,read_excel)
importFrom(rlang,.data)
importFrom(stats,setNames)
importFrom(tibble,as_tibble)
importFrom(tibble,tibble)
importFrom(tidyr,pivot_longer)
importFrom(tidyr,pivot_wider)
importFrom(utils,person)
importFrom(utils,unzip)
importFrom(xml2,read_html)
importFrom(xml2,xml_attr)
importFrom(xml2,xml_find_all)
importFrom(xml2,xml_text)
